pub enum ProtocolTxType {
EthereumEvents,
BridgePool,
ValidatorSetUpdate,
EthEventsVext,
BridgePoolVext,
ValSetUpdateVext,
}Expand description
Types of protocol messages to be sent
Variants
EthereumEvents
Ethereum events contained in vote extensions that are compressed before being included on chain
BridgePool
Collection of signatures over the Ethereum bridge pool merkle root and nonce.
ValidatorSetUpdate
Validator set updates contained in vote extensions
EthEventsVext
Ethereum events seen by some validator
BridgePoolVext
Signature over the Ethereum bridge pool merkle root and nonce.
ValSetUpdateVext
Validator set update signed by some validator
Implementations
Sourceimpl ProtocolTxType
impl ProtocolTxType
Sourcepub fn is_ethereum(&self) -> bool
pub fn is_ethereum(&self) -> bool
Determine if this ProtocolTxType is an Ethereum
protocol tx.